@@ -12,14 +12,10 @@ use Carp 1.04 ();
 use Getopt::Long 2.35 ();
 use Text::ParseWords 3.1 ();
 
-=head1 App::Ack::ConfigLoader
-
 =head1 FUNCTIONS
 
 =head2 process_args( @sources )
 
-
-
 =cut
 
 my @INVALID_COMBINATIONS;
@@ -49,6 +45,7 @@ BEGIN {
     );
 }
 
+
 sub process_filter_spec {
     my ( $spec ) = @_;
 
@@ -73,6 +70,7 @@ sub process_filter_spec {
     }
 }
 
+
 sub uninvert_filter {
     my ( $opt, @filters ) = @_;
 
@@ -92,6 +90,7 @@ sub uninvert_filter {
     }
 }
 
+
 sub process_filetypes {
     my ( $opt, $arg_sources ) = @_;
 
@@ -183,6 +182,7 @@ sub process_filetypes {
     return \%additional_specs;
 }
 
+
 sub removed_option {
     my ( $option, $explanation ) = @_;
 
@@ -193,6 +193,7 @@ sub removed_option {
     };
 }
 
+
 sub get_arg_spec {
     my ( $opt, $extra_specs ) = @_;
 
@@ -345,10 +346,12 @@ EOT
     }; # arg_specs
 }
 
+
 sub process_other {
     my ( $opt, $extra_specs, $arg_sources ) = @_;
 
-    Getopt::Long::Configure('default', 'no_auto_help', 'no_auto_version'); # start with default options, minus some annoying ones
+    # Start with default options, minus some annoying ones.
+    Getopt::Long::Configure('default', 'no_auto_help', 'no_auto_version');
     Getopt::Long::Configure(
         'bundling',
         'no_ignore_case',
@@ -424,10 +427,10 @@ sub process_other {
     return;
 }
 
+
 sub should_dump_options {
     my ( $sources ) = @_;
 
-
     foreach my $source (@{$sources}) {
         my ( $name, $options ) = @{$source}{qw/name contents/};
 
@@ -445,6 +448,7 @@ sub should_dump_options {
     return;
 }
 
+
 sub explode_sources {
     my ( $sources ) = @_;
 
@@ -506,6 +510,7 @@ sub explode_sources {
     return \@new_sources;
 }
 
+
 sub compare_opts {
     my ( $a, $b ) = @_;
 
@@ -518,6 +523,7 @@ sub compare_opts {
     return $first_a cmp $first_b;
 }
 
+
 sub dump_options {
     my ( $sources ) = @_;
 
@@ -546,6 +552,7 @@ sub dump_options {
     return;
 }
 
+
 sub remove_default_options_if_needed {
     my ( $sources ) = @_;
 
@@ -597,6 +604,7 @@ sub remove_default_options_if_needed {
     return \@copy;
 }
 
+
 sub check_for_mutually_exclusive_options {
     my ( $arg_sources ) = @_;
 
@@ -647,6 +655,7 @@ sub check_for_mutually_exclusive_options {
     }
 }
 
+
 sub process_args {
     my $arg_sources = \@_;
 
@@ -729,7 +738,7 @@ sub retrieve_arg_sources {
 
     push @arg_sources, {
         name     => 'Defaults',
-        contents => [ App::Ack::ConfigDefault::options() ],
+        contents => [ App::Ack::ConfigDefault::options_clean() ],
     };
 
     foreach my $file ( @files) {
